==> oatspower-0.0.13.tar.gz: oatspower-0.0.13/README.md <==
![](https://badge.fury.io/py/oatspower.svg)
![](https://img.shields.io/badge/License-GNU%20General%20Public%20License%20v3.0-yellow)
![](https://img.shields.io/badge/Python-2.7.x%20%7C%203.x-red)
# OATS

Optimisation and Analysis Toolbox for power Systems (OATS) is a high-level modelling and simulation tool for power system analysis, developed at the [University of Strathclyde](https://www.strath.ac.uk/engineering/electronicelectricalengineering/). OATS is a collection of optimisation models and Python scripts for analysis and solution of a range of power system analysis problems.
<p align="center">
  <img  height="300" src="https://github.com/bukhsh/oats/blob/master/logo.png">
</p>

## Getting started
The scripts in OATS are written in Python 2. The optimisation models are written in PYOMO, which is an algebraic modelling language. A solver is required to solve the optimisation models.

## Documentation
The [documentation](https://oats.readthedocs.io) of OATS is a best place to start. The documentation provides installation instructions and brief description of the optimisation models that are implemented in OATS.

## Contributing
Any issues with the code and/or software bugs in OATS should be raised through the GitHub page.

Users are encouraged to contribute to improve OATS. Contributions can be in the form of improved optimisation models or in the form of data sets.

Please note that the users are obliged to share the code derived from OATS under the license terms.

## License

OATS is distributed under the open source license GNU GPL v3 - see the [LICENSE](LICENSE.md) file for details. This is a copyleft license that requires anyone using this code or a derivative work to make the source available under the same terms.

## Authors
* **Waqquas Bukhsh** - *Initial work* - [University of Strathclyde](https://github.com/bukhsh/)

See also the list of [contributors](https://github.com/bukhsh/oats/contributors) who participated in this project.

## Citing OATS

We are working on a journal article for OATS. Meanwhile, we request the users to cite the user manual of OATS.

* W. Bukhsh, OATS: Optimisation and Analysis Toolbox for Power Systems Optimisation, Documentation release 0.1, 2017 \[Available\] Online: https://github.com/bukhsh/oats

## Acknowledgments

* [GARPUR](https://www.sintef.no/projectweb/garpur)
* [RESTLESS](http://gow.epsrc.ac.uk/NGBOViewGrant.aspx?GrantRef=EP/N001893/1)
* [University of Strathclyde](https://www.strath.ac.uk/)

==> oatspower-0.0.15.tar.gz: oatspower-0.0.15/README.md <==
![](https://badge.fury.io/py/oatspower.svg)
![](https://img.shields.io/badge/License-GNU%20General%20Public%20License%20v3.0-yellow)
![](https://img.shields.io/badge/Python-2.7.x%20%7C%203.x-red)
# OATS

Optimisation and Analysis Toolbox for power Systems (OATS) is a high-level modelling and simulation tool for power system analysis, developed at the [University of Strathclyde](https://www.strath.ac.uk/engineering/electronicelectricalengineering/). OATS is a collection of optimisation models and Python scripts for analysis and solution of a range of power system analysis problems.
<p align="center">
  <img  height="300" src="https://raw.githubusercontent.com/bukhsh/oats/master/logo.png">
</p>

## Getting started
The scripts in OATS are written in Python 2. The optimisation models are written in PYOMO, which is an algebraic modelling language. A solver is required to solve the optimisation models.

## Documentation
The [documentation](https://oats.readthedocs.io) of OATS is a best place to start. The documentation provides installation instructions and brief description of the optimisation models that are implemented in OATS.

## Contributing
Any issues with the code and/or software bugs in OATS should be raised through the GitHub page.

Users are encouraged to contribute to improve OATS. Contributions can be in the form of improved optimisation models or in the form of data sets.

Please note that the users are obliged to share the code derived from OATS under the license terms.

## License

OATS is distributed under the open source license GNU GPL v3 - see the [LICENSE](LICENSE.md) file for details. This is a copyleft license that requires anyone using this code or a derivative work to make the source available under the same terms.

## Authors
* **Waqquas Bukhsh** - *Initial work* - [University of Strathclyde](https://github.com/bukhsh/)

See also the list of [contributors](https://github.com/bukhsh/oats/contributors) who participated in this project.

## Citing OATS

We are working on a journal article for OATS. Meanwhile, we request the users to cite the user manual of OATS.

* W. Bukhsh, OATS: Optimisation and Analysis Toolbox for Power Systems Optimisation, Documentation release 0.1, 2017 \[Available\] Online: https://github.com/bukhsh/oats

## Acknowledgments

* [GARPUR](https://www.sintef.no/projectweb/garpur)
* [RESTLESS](http://gow.epsrc.ac.uk/NGBOViewGrant.aspx?GrantRef=EP/N001893/1)
* [University of Strathclyde](https://www.strath.ac.uk/)
